package com.faraphel.tasks_valider.connectivity.packets

import kotlinx.serialization.Serializable
import kotlinx.serialization.encodeToString
import kotlinx.serialization.json.Json


/**
 * Base for a packet that can be encoded and decoded for a Socket
 */
@Serializable
sealed class BasePacket {
    companion object {
        /**
         * Create a new instance from an array of bytes.
         * @param data: data obtained from the toBytes function.
         */
        inline fun <reified Packet: BasePacket> fromBytes(data: ByteArray): Packet {
            return Json.decodeFromString<Packet>(data.toString())
        }
    }

    /**
     * Encode the content of the packet into an array of bytes
     */
    fun toBytes(): ByteArray {
        return Json.encodeToString(this).encodeToByteArray()
    }
}
