package com.faraphel.tasks_valider.connectivity.room

import android.util.Log
import com.faraphel.tasks_valider.connectivity.packets.BasePacket
import com.faraphel.tasks_valider.connectivity.packets.PacketPing
import java.net.InetAddress
import java.net.InetSocketAddress
import java.net.Socket


/**
 * A client to handle the room connection.
 * @param address the address of the server
 * @param port the port of the server
 */
class RoomClient(
    private val address: InetAddress,
    private val port: Int
) {
    private val server = Socket()

    fun start() {
        Log.d("room-client", "connecting to the server...")
        try {
            server.connect(InetSocketAddress(address, port), 10_000)
        } catch (exception: Exception) {
            Log.e("room-client", "could not connect to the server", exception)
            return
        }
        Log.d("room-client", "connection successful !")

        val serverIn = server.getInputStream()
        val serverOut = server.getOutputStream()

        serverOut.write(PacketPing.toBytes())
        val data = serverIn.readBytes()
        val packet = BasePacket.fromBytes<PacketPing>(data)

        Log.d("room-client", packet.toString())
    }
}