package com.faraphel.tasks_valider.connectivity.room

import android.util.Log
import com.faraphel.tasks_valider.connectivity.packets.PacketPing
import java.net.ServerSocket
import java.net.Socket


/**
 * A server to handle the room connection.
 * @param port the port of the server
 * @param timeout the timeout for a client (in milliseconds)
 */
class RoomServer(
    private val port: Int,
    private val timeout: Int = 10_000
) {
    private var server = ServerSocket(port)

    init {
        server.soTimeout = 0  // accepting clients take an infinite timeout
    }

    /**
     * Accept and treat a client
     */
    private fun handleClient(client: Socket) {
        // TODO(Faraphel): should every client be handled in a new small thread ?
        //  Create the thread here and handle it until the connection is broken

        val clientIn = client.getInputStream()
        val clientOut = client.getOutputStream()

        Log.i("room-server", "data: ${PacketPing.toBytes().toList()}")
        clientOut.write(PacketPing.toBytes())
    }

    /**
     * Accept connections and treat them
     */
    fun start() {
        Thread {
            while (true) {
                val client = server.accept()
                client.soTimeout = timeout  // set the timeout for the communication
                this.handleClient(client)
            }
        }.start()
    }
}
