package com.faraphel.tasks_valider.ui.screen.room

import android.net.wifi.p2p.WifiP2pConfig
import android.net.wifi.p2p.WifiP2pDevice
import android.net.wifi.p2p.WifiP2pDeviceList
import android.net.wifi.p2p.WifiP2pInfo
import android.net.wifi.p2p.WifiP2pManager
import android.util.Log
import androidx.compose.foundation.layout.Column
import androidx.compose.material3.Text
import androidx.compose.runtime.Composable
import androidx.compose.runtime.mutableStateOf
import androidx.compose.runtime.remember
import com.faraphel.tasks_valider.connectivity.room.RoomClient
import com.faraphel.tasks_valider.connectivity.wifi_p2p.WifiP2pHelper
import com.faraphel.tasks_valider.ui.screen.tasks.TaskGroupScreen
import com.faraphel.tasks_valider.ui.widgets.connectivity.WifiP2pDeviceListWidget


/**
 * This screen allow the user to join a room
 */
@Composable
fun RoomClientScreen(wifiP2pHelper: WifiP2pHelper) {
    val peers = remember { mutableStateOf<WifiP2pDeviceList?>(null) }
    val selectedDevice = remember { mutableStateOf<WifiP2pDevice?>(null) }
    val connected = remember { mutableStateOf(false) }

    // if the device is connected to a host, display the main screen
    if (connected.value) {
        TaskGroupScreen()
    }

    // if a device is selected, connect to it
    if (selectedDevice.value != null) {
        // configure the connection to point to the selected device
        val config = WifiP2pConfig().apply {
            deviceAddress = selectedDevice.value!!.deviceAddress
        }
        // try to connect
        wifiP2pHelper.connect(config, object : WifiP2pManager.ActionListener {
            override fun onSuccess() {
                Log.i("room", "Connection successful to the host !")
                // request additional information about the connection to obtain the host IP
                wifiP2pHelper.registerListener(
                    WifiP2pManager.WIFI_P2P_CONNECTION_CHANGED_ACTION,
                    { connectionInfo: WifiP2pInfo ->
                        val client = RoomClient(
                            connectionInfo.groupOwnerAddress,
                            9876  // TODO(Faraphel): port should be a settings
                        )
                        Thread {
                            client.start()
                        }.start()

                        connected.value = true
                    },
                    once = true
                )
            }

            override fun onFailure(reason: Int) {
                // TODO(Faraphel): for most of theses messages, shouldn't a toast be used instead ?
                Log.e("room", "Could not connect to this host. Reason: $reason")
            }
        })
        return
    }

    // let the user pick which host he wishes to connect to

    Column {
        Text(text = "Find a Server")
        // display all the devices that are owner of their group
        WifiP2pDeviceListWidget(
            peers = peers.value,
            filter = { device: WifiP2pDevice -> device.isGroupOwner },
            selectedDevice,
        )
    }

    // TODO(Faraphel): might be doubtful. Test with more phones, should it only run once ? refresh button ?
    // update the list when a new device is detected
    wifiP2pHelper.registerListener(
        WifiP2pManager.WIFI_P2P_PEERS_CHANGED_ACTION,
        { newPeers: WifiP2pDeviceList? -> peers.value = newPeers },
    )
    wifiP2pHelper.discoverPeers()
}