package com.faraphel.tasks_valider.ui.screen.room

import android.net.wifi.p2p.WifiP2pManager
import android.util.Log
import androidx.compose.foundation.layout.*
import androidx.compose.foundation.text.KeyboardOptions
import androidx.compose.material3.*
import androidx.compose.runtime.Composable
import androidx.compose.runtime.mutableStateOf
import androidx.compose.runtime.remember
import androidx.compose.ui.Modifier
import androidx.compose.ui.text.input.KeyboardType
import com.faraphel.tasks_valider.connectivity.wifi_p2p.WifiP2pHelper
import com.faraphel.tasks_valider.ui.screen.tasks.TaskGroupScreen
import java.net.ServerSocket


var DEFAULT_SERVER_PORT: Int = 9876


/**
 * This screen allow the user to create a room
 */
@Composable
fun RoomHostScreen(wifiP2pHelper: WifiP2pHelper) {
    val expanded = remember { mutableStateOf(false) }
    val serverPort = remember { mutableStateOf(DEFAULT_SERVER_PORT) }
    val isCreated = remember { mutableStateOf(false) }

    // if the group have been created, display the group screen
    if (isCreated.value) {
        TaskGroupScreen()
        return
    }

    // ask the user settings about the room
    Column {
        Box(Modifier.fillMaxWidth()) {
            // dropdown button
            Button(onClick = { expanded.value = !expanded.value }) {
                Text(text = "Select Students List")
            }
            // dropdown list
            DropdownMenu(
                expanded = expanded.value,
                onDismissRequest = { expanded.value = false }
            ) {
                DropdownMenuItem(
                    text = { Text("ISRI") },
                    onClick = {}
                )
                DropdownMenuItem(
                    text = { Text("MIAGE") },
                    onClick = {}
                )
            }
        }

        // ask the user what will be the server port
        TextField(
            value = serverPort.value.toString(),
            keyboardOptions = KeyboardOptions(keyboardType = KeyboardType.Number),
            onValueChange = { value -> serverPort.value = value.toIntOrNull() ?: DEFAULT_SERVER_PORT }
        )

        Button(onClick = {
            // create a new WiFi-Direct group
            wifiP2pHelper.recreateGroup(object : WifiP2pManager.ActionListener {
                override fun onSuccess() {
                    Log.i("room", "group created !")

                    val server = ServerSocket(serverPort.value)  // TODO(Faraphel): should the port be a settings ?
                    Thread {
                        val client = server.accept()  // TODO(Faraphel): should run in a thread
                        client.getInputStream()
                    }

                    // mark the group as created
                    isCreated.value = true
                }
                override fun onFailure(reason: Int) {
                    Log.e("room", "error while creating group. Reason: $reason")
                }
            })
        }) {
            Text("Create")
        }
    }

}
