package com.faraphel.tasks_valider.ui.screen.room

import androidx.compose.foundation.layout.Column
import androidx.compose.material3.Button
import androidx.compose.material3.Text
import androidx.compose.runtime.Composable
import androidx.compose.runtime.mutableStateOf
import androidx.compose.runtime.remember
import com.faraphel.tasks_valider.connectivity.wifi_p2p.WifiP2pHelper


enum class RoomScreenType {
    HOST,
    CLIENT
}


/**
 * This screen will allow the user to choose which room is he connecting to, or let him create one.
 */
@Composable
fun RoomScreen(wifiP2pHelper: WifiP2pHelper) {
    val roomMode = remember { mutableStateOf<RoomScreenType?>(null) }

    when (roomMode.value) {
        RoomScreenType.CLIENT -> {
            // Client mode
            RoomClientScreen(wifiP2pHelper)
        }
        RoomScreenType.HOST -> {
            // Host mode
            RoomHostScreen(wifiP2pHelper)
        }

        null -> {
            // let the user decide which room mode he which to use
            Column {
                Button(onClick = { roomMode.value = RoomScreenType.CLIENT }) {
                    Text(text = "Join a room")
                }
                Button(onClick = { roomMode.value = RoomScreenType.HOST }) {
                    Text(text = "Create a room")
                }
            }
        }
    }
}